@@ -5,7 +5,7 @@ use base 'PDF::API2::Resource';
 use strict;
 use warnings;
 
-our $VERSION = '2.030'; # VERSION
+our $VERSION = '2.033'; # VERSION
 
 sub new {
     my ($class, $pdf, $name) = @_;
@@ -16,7 +16,4 @@ sub new {
     return $self;
 }
 
-# Deprecated (rolled into new)
-sub new_api { my $self = shift(); return $self->new(@_); }
-
 1;
